@@ -4,7 +4,7 @@ BEGIN {
   $Class::MOP::Method::Constructor::AUTHORITY = 'cpan:STEVAN';
 }
 BEGIN {
-  $Class::MOP::Method::Constructor::VERSION = '2.0101'; # TRIAL
+  $Class::MOP::Method::Constructor::VERSION = '2.0102'; # TRIAL
 }
 
 use strict;
@@ -73,16 +73,6 @@ sub _new {
 sub options              { (shift)->{'options'}              }
 sub associated_metaclass { (shift)->{'associated_metaclass'} }
 
-## cached values ...
-
-sub _attributes {
-    my $self = shift;
-    $self->{'attributes'} ||= [
-        sort { $a->name cmp $b->name }
-             $self->associated_metaclass->get_all_attributes
-    ]
-}
-
 ## method
 
 sub _initialize_body {
@@ -96,10 +86,7 @@ sub _initialize_body {
 
 sub _eval_environment {
     my $self = shift;
-    my $defaults = [map { $_->default } @{ $self->_attributes }];
-    return {
-        '$defaults' => \$defaults,
-    };
+    return $self->associated_metaclass->_eval_environment;
 }
 
 sub _generate_constructor_method {
@@ -144,7 +131,7 @@ Class::MOP::Method::Constructor - Method Meta Object for constructors
 
 =head1 VERSION
 
-version 2.0101
+version 2.0102
 
 =head1 SYNOPSIS
 
