@@ -3,7 +3,7 @@ BEGIN {
   $Moose::Meta::Method::Accessor::Native::AUTHORITY = 'cpan:STEVAN';
 }
 BEGIN {
-  $Moose::Meta::Method::Accessor::Native::VERSION = '2.0101'; # TRIAL
+  $Moose::Meta::Method::Accessor::Native::VERSION = '2.0102'; # TRIAL
 }
 
 use strict;
@@ -26,7 +26,16 @@ around new => sub {
         unless $options{curried_arguments}
             && ref($options{curried_arguments}) eq 'ARRAY';
 
-    $options{definition_context} = $options{attribute}->definition_context;
+    my $attr_context = $options{attribute}->definition_context;
+    my $desc = 'native delegation method ';
+    $desc   .= $options{attribute}->associated_class->name;
+    $desc   .= '::' . $options{name};
+    $desc   .= " ($options{delegate_to_method})";
+    $desc   .= " of attribute " . $options{attribute}->name;
+    $options{definition_context} = {
+        %{ $attr_context || {} },
+        description => $desc,
+    };
 
     $options{accessor_type} = 'native';
 
